lcvtoolbox.vision.encoding.binary\_mask.encode\_mask\_rle
=========================================================

.. currentmodule:: lcvtoolbox.vision.encoding.binary_mask

.. autofunction:: encode_mask_rle